pub struct RouterProps<T>where
T: Target,{
pub children: Children,
pub default: Option<T>,
pub base: Option<String>,
}Expand description
Properties for the Router component.
Fields
children: ChildrenThe content to render.
default: Option<T>The default target to use in case none matched.
base: Option<String>The application base.
Defaults to an empty string or the content of the href attribute of the <base> element.
This can be used in case the application is hosted on a sub path to adapt paths generated and expected by the router.
Usage with trunk
If you are using trunk to build the application, you can add the following to your
index.html file:
<head>
<base data-trunk-public-url/>
</head>This will automatically populate the <base> element with the root provided using the
--public-url argument.