pub struct History;Implementations
Sourceimpl History
impl History
Sourcepub fn listener<F: Fn() + 'static>(f: F) -> HistoryListener
pub fn listener<F: Fn() + 'static>(f: F) -> HistoryListener
Subscribe to events of the browser history.
This will receive events when popping items from the stack, as well as changes triggered by calling
History::push_state.
Sourcepub fn push_state(state: JsValue, url: &str) -> Result<(), JsValue>
pub fn push_state(state: JsValue, url: &str) -> Result<(), JsValue>
Push a new state to the history stack.
This will send out events and update the browser’s history. Ultimately calling
web_sys::History::push_state_with_url.
Sourcepub fn replace_state(state: JsValue, url: &str) -> Result<(), JsValue>
pub fn replace_state(state: JsValue, url: &str) -> Result<(), JsValue>
Replace current state in the history stack
This will send out events and update the browser’s history. Ultimately calling
web_sys::History::replace_state_with_url.